@@ -72,6 +72,50 @@ class ClienteleHandler(GenericHandler):
         customer.people.append(person)
         return customer
 
+    def get_first_phone(self, customer, **kwargs):
+        """
+        Return the first available phone record found, either for the
+        customer, or its first person.
+        """
+        phone = customer.first_phone()
+        if phone:
+            return phone
+
+        person = self.get_person(customer)
+        if person:
+            return person.first_phone()
+
+    def get_first_phone_number(self, customer, **kwargs):
+        """
+        Return the first available phone number found, either for the
+        customer, or its first person.
+        """
+        phone = self.get_first_phone(customer)
+        if phone:
+            return phone.number
+
+    def get_first_email(self, customer, **kwargs):
+        """
+        Return the first available email record found, either for the
+        customer, or its first person.
+        """
+        email = customer.first_email()
+        if email:
+            return email
+
+        person = self.get_person(customer)
+        if person:
+            return person.first_email()
+
+    def get_first_email_address(self, customer, **kwargs):
+        """
+        Return the first available email address found, either for the
+        customer, or its first person.
+        """
+        email = self.get_first_email(customer)
+        if email:
+            return email.address
+
 
 def get_clientele_handler(config, **kwargs):
     """
