@@ -53,7 +53,8 @@ from .purchase import (PurchaseBase, PurchaseItemBase, PurchaseCreditBase,
                        Purchase, PurchaseItem, PurchaseCredit)
 
 from .custorders import (CustomerOrderBase, CustomerOrderItemBase,
-                         CustomerOrder, CustomerOrderItem, CustomerOrderItemEvent)
+                         CustomerOrder, CustomerOrderItem,
+                         CustomerOrderItemEvent, CustomerOrderItemNote)
 
 from .messages import Message, MessageRecipient
 
