@@ -468,6 +468,16 @@ class Product(Base):
             return True
         return False
 
+    def get_unit_item(self):
+        """
+        Returns the *unit* item for the current product.  If this
+        product *is* a unit item, will return ``self``; otherwise
+        returns ``self.unit``.
+        """
+        if self.is_unit_item():
+            return self
+        return self.unit
+
     def get_default_pack_item(self):
         """
         Returns the "default" pack item for the current product, which is
