@@ -99,6 +99,7 @@ class FromRattailToRattailBase(object):
         importers['PersonEmailAddress'] = PersonEmailAddressImporter
         importers['PersonPhoneNumber'] = PersonPhoneNumberImporter
         importers['PersonMailingAddress'] = PersonMailingAddressImporter
+        importers['MergePeopleRequest'] = MergePeopleRequestImporter
         importers['User'] = UserImporter
         importers['AdminUser'] = AdminUserImporter
         importers['GlobalUser'] = GlobalUserImporter
@@ -256,6 +257,9 @@ class PersonPhoneNumberImporter(FromRattail, model.PersonPhoneNumberImporter):
 class PersonMailingAddressImporter(FromRattail, model.PersonMailingAddressImporter):
     pass
 
+class MergePeopleRequestImporter(FromRattail, model.MergePeopleRequestImporter):
+    pass
+
 class UserImporter(FromRattail, model.UserImporter):
     pass
 
