@@ -1,12 +1,13 @@
-# -*- coding: utf-8 -*-
+# -*- coding: utf-8; -*-
 
-from __future__ import unicode_literals
+from __future__ import unicode_literals, absolute_import
 
 from unittest import TestCase
+from six import StringIO
+
 from mock import patch
 
 from rattail import csvutil
-from cStringIO import StringIO
 
 
 class TestDictWriter(TestCase):
